@@ -3,6 +3,7 @@ import collections
 import dataclasses
 import datetime
 import decimal
+import enum
 import inspect
 import json
 import random
@@ -22,9 +23,9 @@ from .exceptions import NameSpaceRequiredException
 PY_VER = sys.version_info
 
 if PY_VER >= (3, 9):
-    GenericAlias = (typing.GenericAlias, typing._GenericAlias, typing._SpecialGenericAlias, typing._UnionGenericAlias)
+    GenericAlias = (typing.GenericAlias, typing._GenericAlias, typing._SpecialGenericAlias, typing._UnionGenericAlias)  # type: ignore # noqa: E501
 else:
-    GenericAlias = typing._GenericAlias
+    GenericAlias = typing._GenericAlias  # type: ignore
 
 
 fake = Faker()
@@ -62,8 +63,8 @@ PYTHON_TYPE_TO_AVRO = {
     list: {"type": ARRAY},
     tuple: {"type": ARRAY},
     dict: {"type": MAP},
+    enum.Enum: {"type": ENUM},
     types.Fixed: {"type": FIXED},
-    types.Enum: {"type": ENUM},
     types.Int32: INT,
     types.Float32: FLOAT,
     datetime.date: {"type": INT, "logicalType": DATE},
@@ -83,7 +84,7 @@ PYTHON_PRIMITIVE_TYPES = PYTHON_INMUTABLE_TYPES + PYTHON_PRIMITIVE_CONTAINERS
 
 PRIMITIVE_AND_LOGICAL_TYPES = PYTHON_INMUTABLE_TYPES + PYTHON_LOGICAL_TYPES
 
-PythonImnutableTypes = typing.Union[
+PythonImmutableTypes = typing.Union[
     str,
     int,
     types.Int32,
@@ -108,7 +109,7 @@ class BaseField:
     name: str
     type: typing.Any  # store the python primitive type
     default: typing.Any
-    parent: typing.Tuple[dataclasses.Field]
+    parent: typing.Any
     metadata: typing.Mapping = dataclasses.field(default_factory=dict)
     model_metadata: typing.Optional[utils.SchemaMetadata] = None
 
@@ -198,7 +199,7 @@ class BaseField:
 
 
 class ImmutableField(BaseField):
-    def get_avro_type(self) -> PythonImnutableTypes:
+    def get_avro_type(self) -> PythonImmutableTypes:
         if self.default is None:
             return [NULL, self.avro_type]
         return self.avro_type
@@ -280,7 +281,7 @@ class NoneField(ImmutableField):
 class ContainerField(BaseField):
     default_factory: typing.Optional[typing.Callable] = None
 
-    def get_avro_type(self) -> PythonImnutableTypes:
+    def get_avro_type(self) -> PythonImmutableTypes:
         avro_type = self.avro_type
         avro_type["name"] = self.get_singular_name(self.name)
 
@@ -320,11 +321,10 @@ class ListField(ContainerField):
     def generate_items_type(self) -> typing.Any:
         # because avro can have only one type, we take the first one
         items_type = self.type.__args__[0]
-        name = self.get_singular_name(self.name)
 
         if utils.is_union(items_type):
             self.items_type = UnionField(
-                name,
+                self.name,
                 items_type,
                 default=self.default,
                 default_factory=self.default_factory,
@@ -332,7 +332,9 @@ class ListField(ContainerField):
                 parent=self.parent,
             ).get_avro_type()
         else:
-            self.internal_field = AvroField(name, items_type, model_metadata=self.model_metadata, parent=self.parent)
+            self.internal_field = AvroField(
+                self.name, items_type, model_metadata=self.model_metadata, parent=self.parent
+            )
             self.items_type = self.internal_field.get_avro_type()
 
     def fake(self) -> typing.List:
@@ -376,9 +378,7 @@ class DictField(ContainerField):
         so we take the second argument to determine the value type
         """
         values_type = self.type.__args__[1]
-
-        name = self.get_singular_name(self.name)
-        self.internal_field = AvroField(name, values_type, model_metadata=self.model_metadata, parent=self.parent)
+        self.internal_field = AvroField(self.name, values_type, model_metadata=self.model_metadata, parent=self.parent)
         self.values_type = self.internal_field.get_avro_type()
 
     def fake(self) -> typing.Dict[str, typing.Any]:
@@ -448,6 +448,8 @@ class UnionField(BaseField):
             return default
         elif type(self.default) in LOGICAL_CLASSES:
             return LOGICAL_TYPES_FIELDS_CLASSES[type(self.default)].to_avro(self.default)  # type: ignore
+        elif issubclass(type(self.default), enum.Enum):
+            return self.default.value
         return self.default
 
     def fake(self) -> typing.Any:
@@ -483,37 +485,44 @@ class FixedField(BaseField):
 
 @dataclasses.dataclass
 class EnumField(BaseField):
+    def _get_meta_class_attributes(self) -> typing.Dict[str, typing.Any]:
+        # get Enum members
+        members = self.type.__members__
+        meta = members.get("Meta")
+
+        if meta:
+            metadata = utils.FieldMetadata.create(meta.value)
+            return metadata.to_dict()
+        return {}
+
+    def get_symbols(self) -> typing.List[str]:
+        return [member.value for member in self.type if member.name != "Meta"]
+
     def get_avro_type(self) -> typing.Dict[str, typing.Any]:
         avro_type = {
             "type": ENUM,
             "name": self.get_singular_name(self.name),
-            "symbols": self.default.symbols,
+            "symbols": self.get_symbols(),
+            **self._get_meta_class_attributes(),
         }
 
-        if self.default.namespace is not None:
-            avro_type["namespace"] = self.default.namespace
-
-        if self.default.aliases is not None:
-            avro_type["aliases"] = self.default.aliases
-
         return avro_type
 
     def get_default_value(self) -> typing.Union[str, dataclasses._MISSING_TYPE, None]:
-        default = self.default.default
 
-        if default == types.MissingSentinel:
+        if self.default == types.MissingSentinel:
             return dataclasses.MISSING
-        elif default in (dataclasses.MISSING, None):
-            return default
+        elif self.default in (dataclasses.MISSING, None):
+            return self.default
         else:
             # check that the default value is listed in symbols
             assert (
-                default in self.default.symbols
-            ), f"The default value should be on of {self.default.symbols}. Current is {default}"
-            return default
+                self.default.value in self.get_symbols()
+            ), f"The default value should be one of {self.get_symbols()}. Current is {self.default}"
+            return self.default.value
 
     def fake(self) -> typing.Any:
-        return random.choice(self.default.symbols)
+        return random.choice(self.get_symbols())
 
 
 @dataclasses.dataclass
@@ -676,25 +685,26 @@ class UUIDField(LogicalTypeField):
 @dataclasses.dataclass
 class RecordField(BaseField):
     def get_avro_type(self) -> typing.Union[typing.List, typing.Dict]:
-        alias = self.model_metadata.get_alias(self.name)  # type: ignore
-        name = alias or self.type.__name__
+        meta = getattr(self.type, "Meta", None)
+        metadata = utils.SchemaMetadata.create(meta)
+
+        alias = self.parent.metadata.get_alias_nested_items(self.name) or metadata.get_alias_nested_items(self.name)  # type: ignore  # noqa E501
+
+        # The priority for the schema name
+        # 1. Check if the schema_name is present in the Meta class of own model
+        # 2. Check if exists an alias_nested_items in parent class or Meta class of own model
+        # 3. Use the default class Name (self.type.__name__)
+        name = metadata.schema_name or alias or self.type.__name__
 
         if not self.exist_type():
             user_defined_type = utils.UserDefinedType(name=name, type=self.type)
 
             # add user_defined_type to the parent
-            self.parent.user_defined_types = self.parent.user_defined_types + (user_defined_type,)
+            self.parent.user_defined_types += (user_defined_type,)
 
-            # add the parent define types to the current self.type (AvroModel) to generate valid avro schemas
-            # when inheritance has more than 2 levels
-            self.type.user_defined_types = self.type.user_defined_types + self.parent.user_defined_types
-
-            record_type = self.type.avro_schema_to_python()
+            record_type = self.type.avro_schema_to_python(root=self.parent)
             record_type["name"] = name
         else:
-            meta = getattr(self.type, "Meta", None)
-            metadata = utils.SchemaMetadata.create(meta)
-
             if metadata.namespace is None:
                 raise NameSpaceRequiredException(field_type=self.type, field_name=self.name)
             record_type = f"{metadata.namespace}.{name}"
@@ -706,7 +716,7 @@ class RecordField(BaseField):
     def fake(self) -> typing.Any:
         return self.type.fake()
 
-    def exist_type(self):
+    def exist_type(self) -> int:
         # filter by the same field types
         same_types = [
             field.type
@@ -824,7 +834,6 @@ PRIMITIVE_LOGICAL_TYPES_FIELDS_CLASSES = {
     **INMUTABLE_FIELDS_CLASSES,
     **LOGICAL_TYPES_FIELDS_CLASSES,  # type: ignore
     types.Fixed: FixedField,
-    types.Enum: EnumField,
 }
 
 LOGICAL_CLASSES = LOGICAL_TYPES_FIELDS_CLASSES.keys()
@@ -889,15 +898,6 @@ def field_factory(
             model_metadata=model_metadata,
             parent=parent,
         )
-    elif native_type is types.Enum:
-        return EnumField(
-            name=name,
-            type=native_type,
-            default=default,
-            metadata=metadata,
-            model_metadata=model_metadata,
-            parent=parent,
-        )
     elif isinstance(native_type, GenericAlias):  # type: ignore
         origin = native_type.__origin__
 
@@ -938,6 +938,15 @@ def field_factory(
             model_metadata=model_metadata,
             parent=parent,
         )
+    elif inspect.isclass(native_type) and issubclass(native_type, enum.Enum):
+        return EnumField(
+            name=name,
+            type=native_type,
+            default=default,
+            metadata=metadata,
+            model_metadata=model_metadata,
+            parent=parent,
+        )
     elif inspect.isclass(native_type) and issubclass(native_type, schema_generator.AvroModel):
         return RecordField(
             name=name,
