@@ -1,16 +1,18 @@
 import dataclasses
+import enum
+import inspect
 import json
 import typing
 from collections import OrderedDict
 
 from dacite import Config, from_dict
+from fastavro.validation import validate
 
-from dataclasses_avroschema import case, utils
-from dataclasses_avroschema.schema_definition import AvroSchemaDefinition
-from dataclasses_avroschema.serialization import deserialize, serialize, to_json
-from dataclasses_avroschema.utils import SchemaMetadata, is_custom_type
-
-from .fields import FieldType
+from . import case
+from .fields import EnumField, FieldType, RecordField, UnionField
+from .schema_definition import AvroSchemaDefinition
+from .serialization import deserialize, serialize, to_json
+from .utils import SchemaMetadata, is_custom_type, is_pydantic_model
 
 AVRO = "avro"
 AVRO_JSON = "avro-json"
@@ -24,12 +26,13 @@ class AvroModel:
     schema_def: typing.Optional[AvroSchemaDefinition] = None
     klass: typing.Any = None
     metadata: typing.Optional[SchemaMetadata] = None
-    user_defined_types: typing.Tuple[utils.UserDefinedType] = ()
+    user_defined_types: typing.Tuple = ()
+    root: typing.Any = None
     rendered_schema: typing.Optional[OrderedDict] = None
 
     @classmethod
     def generate_dataclass(cls: typing.Any) -> typing.Any:
-        if dataclasses.is_dataclass(cls):
+        if dataclasses.is_dataclass(cls) or is_pydantic_model(cls):
             return cls
         return dataclasses.dataclass(cls)
 
@@ -40,7 +43,7 @@ class AvroModel:
         return SchemaMetadata.create(meta)
 
     @classmethod
-    def generate_schema(cls: typing.Type[CT], schema_type: str = "avro") -> AvroSchemaDefinition:
+    def generate_schema(cls: typing.Type[CT], schema_type: str = "avro") -> typing.Optional[OrderedDict]:
         if cls.schema_def is None:
             # Generate metaclass and metadata
             cls.klass = cls.generate_dataclass()
@@ -59,7 +62,7 @@ class AvroModel:
 
     @classmethod
     def _generate_avro_schema(cls: typing.Any) -> AvroSchemaDefinition:
-        return AvroSchemaDefinition("record", cls.klass, metadata=cls.metadata, parent=cls)
+        return AvroSchemaDefinition("record", cls.klass, metadata=cls.metadata, parent=cls.root or cls)
 
     @classmethod
     def avro_schema(cls: typing.Any, case_type: typing.Optional[str] = None) -> str:
@@ -74,7 +77,10 @@ class AvroModel:
         return json.dumps(avro_schema)
 
     @classmethod
-    def avro_schema_to_python(cls: typing.Any) -> typing.Dict[str, typing.Any]:
+    def avro_schema_to_python(cls: typing.Any, root: typing.Any = None) -> typing.Dict[str, typing.Any]:
+        if root is not None:
+            cls.root = root
+
         return json.loads(cls.avro_schema())
 
     @classmethod
@@ -83,10 +89,44 @@ class AvroModel:
             cls.generate_schema()
         return cls.schema_def.fields
 
+    @classmethod
+    def _get_enum_type_map(cls: typing.Any) -> typing.Dict[str, enum.Enum]:
+        enum_types = {}
+        for field_type in cls.get_fields():
+            if isinstance(field_type, EnumField):
+                enum_types[field_type.name] = field_type.type
+            elif isinstance(field_type, UnionField):
+                for sub_type in field_type.type.__args__:
+                    if inspect.isclass(sub_type) and issubclass(sub_type, enum.Enum):
+                        enum_types[field_type.name] = sub_type
+            elif isinstance(field_type, RecordField):
+                enum_types.update(field_type.type._get_enum_type_map())
+        return enum_types
+
+    @classmethod
+    def _deserialize_complex_types(cls, payload: typing.Dict[str, typing.Any]) -> typing.Any:
+        output = {}
+        enum_type_map = cls._get_enum_type_map()
+        for field, value in payload.items():
+            if isinstance(value, dict):
+                output[field] = cls._deserialize_complex_types(value)
+            elif field in enum_type_map and isinstance(value, str):
+                try:
+                    output[field] = enum_type_map[field](value)
+                except ValueError as e:
+                    raise ValueError(f"Value {value} is not a valid instance of {enum_type_map[field]}", e)
+            else:
+                output[field] = value
+        return output
+
     @staticmethod
     def standardize_custom_type(value: typing.Any) -> typing.Any:
         if is_custom_type(value):
             return value["default"]
+        elif isinstance(value, dict):
+            return {k: AvroModel.standardize_custom_type(v) for k, v in value.items()}
+        elif issubclass(type(value), enum.Enum):
+            return value.value
         return value
 
     def asdict(self) -> JsonDict:
@@ -110,29 +150,44 @@ class AvroModel:
         writer_schema: typing.Optional[typing.Union[JsonDict, CT]] = None,
     ) -> typing.Union[JsonDict, CT]:
 
-        try:
+        if inspect.isclass(writer_schema) and issubclass(writer_schema, AvroModel):
             writer_schema = writer_schema.avro_schema_to_python()
-        except AttributeError:
-            pass
 
         schema = cls.avro_schema_to_python()
         payload = deserialize(data, schema, serialization_type=serialization_type, writer_schema=writer_schema)
+        output = cls._deserialize_complex_types(payload)
 
         if create_instance:
-            return from_dict(data_class=cls, data=payload, config=Config(**cls.config()))
-        return payload
+            return cls.parse_obj(data=output)
+        return output
 
-    def to_json(self) -> JsonDict:
+    @classmethod
+    def parse_obj(cls, data: typing.Dict) -> typing.Union[JsonDict, CT]:
+        return from_dict(data_class=cls, data=data, config=Config(**cls.config()))
+
+    def validate(self) -> bool:
+        schema = self.avro_schema_to_python()
+        return validate(self.asdict(), schema)
+
+    def to_dict(self) -> JsonDict:
         # Serialize using the current AVRO schema to get proper field representations
         # and after that convert into python
-        data = self.asdict()
-        return to_json(data)
+        return self.asdict()
+
+    def to_json(self):
+        data = to_json(self.asdict())
+        return json.dumps(data)
 
     @classmethod
     def config(cls) -> JsonDict:
         """
         Get the default config for dacite and always include the self reference
         """
+        # We need to make sure that the `avro schemas` has been generated, otherwise cls.klass is empty
+        # It won't affect the performance because the rendered schema will be store in cls.rendered_schema
+        if cls.klass is None:
+            cls.avro_schema()
+
         return {
             "check_types": False,
             "forward_references": {
